@@ -4,7 +4,7 @@ from os import path
 from .structures import Structures
 
 
-def write_match_output(structures: Structures, odir_match: str):
+def write_match_output(structures: Structures, odir_match: str) -> None:
     """
     Save Tregex's match output
 
@@ -20,16 +20,14 @@ def write_match_output(structures: Structures, odir_match: str):
         os.makedirs(subdir_match_output)
     for structure in structures.to_search_for:
         bn_match_output = bn_input_rstripped + "-" + structure.name + ".matches"
-        bn_tex_output = bn_input_rstripped + "-" + structure.name + ".tex"
         fn_match_output = path.join(subdir_match_output, bn_match_output)
-        fn_tex_output = path.join(subdir_match_output, bn_tex_output)
         if structure.matches:
             with open(fn_match_output, "w", encoding="utf-8") as f:
                 f.write(structure.matches)
     print(f"Match output was saved to {subdir_match_output}")
 
 
-def write_freq_output(freq_output: str, ofile_freq: str):
+def write_freq_output(freq_output: str, ofile_freq: str) -> None:
     """
     :param freq_output: comma-separated frequency output
     :param fn_output: where to save the frequency output
